@@ -173,17 +173,60 @@ function copyPrefOverride() {
   }
 }
 
-function openWindow(parent, url, target, features, args) {
+// Flag used to indicate that the arguments to openWindow can be passed directly.
+const NO_EXTERNAL_URIS = 1;
+
+function openWindow(parent, url, target, features, args, noExternalArgs) {
   var wwatch = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                          .getService(nsIWindowWatcher);
 
-  var argstring;
-  if (args) {
-    argstring = Components.classes["@mozilla.org/supports-string;1"]
+  if (noExternalArgs == NO_EXTERNAL_URIS) {
+    // Just pass in the defaultArgs directly
+    var argstring;
+    if (args) {
+      argstring = Components.classes["@mozilla.org/supports-string;1"]
                             .createInstance(nsISupportsString);
-    argstring.data = args;
+      argstring.data = args;
+    }
+
+    return wwatch.openWindow(parent, url, target, features, argstring);
   }
-  return wwatch.openWindow(parent, url, target, features, argstring);
+  
+  // Pass an array to avoid the browser "|"-splitting behavior.
+  var argArray = Components.classes["@mozilla.org/supports-array;1"]
+                    .createInstance(Components.interfaces.nsISupportsArray);
+
+  // add args to the arguments array
+  var stringArgs = null;
+  if (args instanceof Array) // array
+    stringArgs = args;
+  else if (args) // string
+    stringArgs = [args];
+
+  if (stringArgs) {
+    // put the URIs into argArray
+    var uriArray = Components.classes["@mozilla.org/supports-array;1"]
+                       .createInstance(Components.interfaces.nsISupportsArray);
+    stringArgs.forEach(function (uri) {
+      var sstring = Components.classes["@mozilla.org/supports-string;1"]
+                              .createInstance(nsISupportsString);
+      sstring.data = uri;
+      uriArray.AppendElement(sstring);
+    });
+    argArray.AppendElement(uriArray);
+  } else {
+    argArray.AppendElement(null);
+  }
+
+  // Pass these as null to ensure that we always trigger the "single URL"
+  // behavior in browser.js's BrowserStartup (which handles the window
+  // arguments)
+  argArray.AppendElement(null); // charset
+  argArray.AppendElement(null); // referer
+  argArray.AppendElement(null); // postData
+  argArray.AppendElement(null); // allowThirdPartyFixup
+
+  return wwatch.openWindow(parent, url, target, features, argArray);
 }
 
 function openPreferences() {
@@ -204,14 +247,14 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 215 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 258 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 222 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 265 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -224,7 +267,7 @@ function getMostRecentBrowserWindow() {
         win = nextWin;
     }
   }
-//@line 247 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 290 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
@@ -294,9 +337,10 @@ var nsBrowserContentHandler = {
   /* nsICommandLineHandler */
   handle : function bch_handle(cmdLine) {
     if (cmdLine.handleFlag("browser", false)) {
+      // Passing defaultArgs, so use NO_EXTERNAL_URIS
       openWindow(null, this.chromeURL, "_blank",
                  "chrome,dialog=no,all" + this.getFeatures(cmdLine),
-                 this.defaultArgs);
+                 this.defaultArgs, NO_EXTERNAL_URIS);
       cmdLine.preventDefault = true;
     }
 
@@ -357,9 +401,10 @@ var nsBrowserContentHandler = {
           if (remoteParams[0].toLowerCase() != "openbrowser")
             throw NS_ERROR_ABORT;
 
+          // Passing defaultArgs, so use NO_EXTERNAL_URIS
           openWindow(null, this.chromeURL, "_blank",
                      "chrome,dialog=no,all" + this.getFeatures(cmdLine),
-                     this.defaultArgs);
+                     this.defaultArgs, NO_EXTERNAL_URIS);
           break;
 
         default:
@@ -427,7 +472,7 @@ var nsBrowserContentHandler = {
         }
         if (!uri.schemeIs("javascript") && !uri.schemeIs("data")) {
           var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
-          openWindow(null, uri.spec, "_blank", features, "");
+          openWindow(null, uri.spec, "_blank", features);
           cmdLine.preventDefault = true;
         }
       }
@@ -448,7 +493,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 483 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 528 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -664,13 +709,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 701 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 746 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 727 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 772 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -732,23 +777,19 @@ var nsDefaultCommandLineHandler = {
         }
       }
 
-      var speclist = [];
-      for (uri in urilist) {
-        if (shouldLoadURI(urilist[uri]))
-          speclist.push(urilist[uri].spec);
-      }
-
-      if (speclist.length) {
+      var URLlist = urilist.filter(shouldLoadURI).map(function (u) { return u.spec; });
+      if (URLlist.length) {
         openWindow(null, nsBrowserContentHandler.chromeURL, "_blank",
                    "chrome,dialog=no,all" + nsBrowserContentHandler.getFeatures(cmdLine),
-                   speclist.join("|"));
+                   URLlist);
       }
 
     }
     else if (!cmdLine.preventDefault) {
+      // Passing defaultArgs, so use NO_EXTERNAL_URIS
       openWindow(null, nsBrowserContentHandler.chromeURL, "_blank",
                  "chrome,dialog=no,all" + nsBrowserContentHandler.getFeatures(cmdLine),
-                 nsBrowserContentHandler.defaultArgs);
+                 nsBrowserContentHandler.defaultArgs, NO_EXTERNAL_URIS);
     }
   },
 
@@ -820,9 +861,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 877 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 918 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 879 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 920 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
